@@ -1,6 +1,6 @@
 <?php
 /**
- * See skin.doc
+ * See skin.txt
  *
  * @todo document
  * @package MediaWiki
@@ -15,7 +15,7 @@ require_once('includes/SkinPHPTal.php');
 if( class_exists( 'SkinPHPTal' ) ) {
 
 /**
- * See skin.doc
+ * See skin.txt
  *
  * @todo document
  * @package MediaWiki
@@ -27,7 +27,6 @@ class SkinChick extends SkinPHPTal {
 		$this->skinname = 'chick';
 		$this->template = 'Chick';
 	}
-	function suppressUrlExpansion() { return true; }
 	function printSource() { return ''; }
 }
 
